import { ControlTypes } from "./types/control-types";
import { ValidationEventTypes } from "./types/validation-event-types";
import { ValidationEvent } from "./types/validation-event";
import { IAbstractControl } from "./types/abstract-control";
import { ValidatorsFunction } from "./types/validators-function";
declare enum PrivateFields {
    tempErrors = "_tempErrors",
    validators = "_validators"
}
export declare abstract class AbstractControl implements IAbstractControl {
    /** Type / Тип контрола **/
    readonly type: ControlTypes;
    /** Validation in progress / В процессе анализа **/
    abstract get processing(): boolean;
    /** Function enable validation by condition (always enabled by default) / Функция включение валидаций по условию (по умолчанию включено всегда) **/
    getActivate?: () => boolean;
    /** Error checking enabled / Проверка ошибок включена  **/
    get active(): boolean;
    /** Error checking is disabled (reverse active) / Проверка ошибок отключена (обратное значение active)  **/
    get disabled(): boolean;
    /** Valid / Валидные данные **/
    abstract get valid(): boolean;
    /** Invalid / Невалидные данные **/
    get invalid(): boolean;
    /** Value changed / Значение изменялось **/
    abstract get dirty(): boolean;
    /** Set marker "value changed" / Изменяет состояния маркета "данные изменены" **/
    abstract set dirty(dirty: boolean);
    /** The value has not changed / Значение не изменялось **/
    get pristine(): boolean;
    /** The field was in focus / Поле было в фокусе **/
    abstract get touched(): boolean;
    /** Set marker "field was out of focus" / Изменяет состояния маркета "значение было в фокусе" **/
    abstract set touched(touched: boolean);
    /** The field was out of focus / Поле не было в фокусе **/
    get untouched(): boolean;
    /** The field is now in focus / Поле сейчас в фокусе **/
    abstract get focused(): boolean;
    /** Set marker "field is now in focus" / Изменяет состояния маркета "Поле сейчас в фокусе" **/
    abstract set focused(focused: boolean);
    protected abstract get _events(): ValidationEvent[][];
    get events(): ValidationEvent[];
    private [PrivateFields.tempErrors];
    /** Additional (server) errors / Дополнительтные (серверные) ошибки **/
    get tempErrors(): string[];
    /** Additional (server) errors / Дополнительтные (серверные) ошибки **/
    set tempErrors(tempErrors: string[]);
    /** Errors list / Список ошибок **/
    get errors(): ValidationEvent[];
    /** The field contains errors / Присутствуют ошибки **/
    get hasErrors(): boolean;
    /** Warnings messages list / Список сообщений с типом "Внимание" **/
    get warnings(): ValidationEvent[];
    /** The field contains warnings messages / Присутствуют сообщения с типом "Внимание" **/
    get hasWarnings(): boolean;
    /** Informations messages list / Сообщения с типом "Информационные сообщения" **/
    get informations(): ValidationEvent[];
    /** The field contains informations messages / Присутствуют сообщения с типом "Информационные сообщения" **/
    get hasInformations(): boolean;
    /** Successes messages list / Сообщения с типом "успешная валидация" **/
    get successes(): ValidationEvent[];
    /** The field contains successes / Присутствуют сообщения с типом "успешная валидация" **/
    get hasSuccesses(): boolean;
    /** Max message level / Максимальный уровень сообщения **/
    get maxEventLevel(): ValidationEventTypes;
    private [PrivateFields.validators];
    get validators(): ValidatorsFunction<IAbstractControl>[];
    /** Additional (server) errors / Дополнительтные (серверные) ошибки **/
    set validators(validators: ValidatorsFunction<IAbstractControl>[]);
    element: HTMLElement | null;
    /** Field for transferring additional information / Поле для передачи дополнительной информации (в логике не участвует) **/
    additionalData?: unknown | null;
    constructor(
    /** Type / Тип контрола **/
    type: ControlTypes);
    /** Dispose (call in unmount react control) / Вызвать при удалении контрола **/
    dispose(): void;
    /** Get error by key / Получить ошибку по ключу */
    event(key: string): ValidationEvent | undefined;
    /** Waiting for end of validation / Ожидание окончания проверки **/
    wait(): Promise<void>;
}
export {};
