import { ValidationEvent } from './types/validation-event';
import { AbstractControl } from './abstract-control';
import { ValidatorsFunction } from './types/validators-function';
declare enum PrivateFields {
    value = "_value",
    dirty = "_dirty",
    touched = "_touched",
    isFocused = "_isFocused",
    reactionValidations = "_reactionValidations"
}
export type UpdateValidValueHandler<TEntity> = (val: TEntity) => void;
export declare class FormControl<TEntity = string> extends AbstractControl {
    /** Validation in progress / В процессе анализа **/
    get processing(): boolean;
    protected get _events(): ValidationEvent[][];
    private [PrivateFields.value];
    get value(): TEntity;
    set value(value: TEntity);
    /** Valid / Валидные данные **/
    get valid(): boolean;
    /** Callback always when value changes / Срабатывает всегда при изменении значения **/
    onChangeValue?: UpdateValidValueHandler<TEntity> | null;
    /** Callback get last valid value / Передает последние валидное значение **/
    onChangeValidValue?: UpdateValidValueHandler<TEntity> | null;
    protected [PrivateFields.dirty]: boolean;
    /** Value changed / Значение изменялось **/
    get dirty(): boolean;
    /** Set marker "value changed" / Изменяет состояния маркета "данные изменены" **/
    set dirty(dirty: boolean);
    protected [PrivateFields.touched]: boolean;
    /** The field was in focus / Поле было в фокусе **/
    get touched(): boolean;
    /** Set marker "field was out of focus" / Изменяет состояния маркета "значение было в фокусе" **/
    set touched(touched: boolean);
    private [PrivateFields.isFocused];
    /** The field is now in focus / Поле сейчас в фокусе **/
    get focused(): boolean;
    /** Set marker "field is now in focus" / Изменяет состояния маркета "Поле сейчас в фокусе" **/
    set focused(focused: boolean);
    private [PrivateFields.reactionValidations];
    private reactionDisposers;
    private initializeCompleted;
    constructor(
    /** Initializing valueI / Инициализирующие значение или его getter */
    valueOrGetterValue: TEntity | (() => TEntity), 
    /** Options / Опции */
    options?: {
        /** Validations / Валидациии **/
        validators?: ValidatorsFunction<FormControl<TEntity>>[];
        /** Function enable validation by condition (always enabled by default) / Функция включение валидаций по условию (по умолчанию включено всегда) **/
        getActivate?: () => boolean;
        /** Callback always when value changes / Срабатывает всегда при изменении значения **/
        onChangeValue?: UpdateValidValueHandler<TEntity> | null;
        /** Callback get last valid value / Передает последние валидное значение **/
        onChangeValidValue?: UpdateValidValueHandler<TEntity> | null;
        /** Invoke `onChangeValidValue` when `FormControl` is created. / Вызвать `onChangeValidValue` при создании `FormControl` **/
        callSetterOnInitialize?: boolean;
        /** Additional information / Блок с дополнительной информацией **/
        additionalData?: unknown | null;
    });
    dispose(): void;
}
export {};
