import { AbstractControl } from './abstract-control';
import { ControlsCollection } from './types/controls-collection';
import { ValidatorsFunction } from './types/validators-function';
import { IAbstractControl } from './types/abstract-control';
import { ValidationEvent } from './types/validation-event';
import { FormControl } from './form-control';
declare enum PrivateFields {
    controls = "_controls",
    reactionValidations = "_reactionValidations"
}
export declare class FormGroup<TControls extends ControlsCollection> extends AbstractControl {
    /** Validation in progress / В процессе анализа **/
    get processing(): boolean;
    protected get _events(): ValidationEvent[][];
    private [PrivateFields.controls];
    get controls(): TControls;
    set controls(controls: TControls);
    /** Valid / Валидные данные **/
    get valid(): boolean;
    get dirty(): boolean;
    /** Set marker "value changed" / Изменяет состояния маркета "данные изменены" **/
    set dirty(dirty: boolean);
    /** The field was in focus / Поле было в фокусе **/
    get touched(): boolean;
    /** Set marker "field was out of focus" / Изменяет состояния маркета "значение было в фокусе" **/
    set touched(touched: boolean);
    get focused(): boolean;
    set focused(focused: boolean);
    get allControlList(): FormControl<unknown>[];
    private get controlList();
    private [PrivateFields.reactionValidations];
    private reactionDisposers;
    constructor(
    /** Сontrols / Контролы */
    controls: TControls, 
    /** Options / Опции */
    options?: {
        /** Validations / Валидациии */
        validators?: ValidatorsFunction<FormGroup<TControls>>[];
        /** Function enable validation by condition (always enabled by default) / Функция включение валидаций по условию (по умолчанию включено всегда) */
        getActivate?: () => boolean;
        /** Additional information / Блок с дополнительной информацией */
        additionalData?: unknown | null;
    });
    dispose(): void;
    protected getProcessing: () => boolean;
    /** Returns a complete list of FormControls without attachments (terminal elements) / Возвращает полный список FormControl-ов без вложений (терминальных элементов) */
    getAllControls(): IterableIterator<FormControl<unknown>>;
    getControls(): IterableIterator<IAbstractControl>;
}
export {};
